@@ -181,17 +181,17 @@ plot.acf <- function(x,
 }
 
 
-#' plot.ts
+#' plotTimesSeries
 #' 
 #' Plot ts object
 #' 
 #' Plot a ts object and, if desired, it's acf and pacf.
 #' 
-#' @aliases plot.ts
+#' @aliases plot.times.series
 #' @author Jared P. Lander
-#' @export plot.ts
-#' @S3method plot ts
-#' @method plot ts
+#' @export plotTimesSeries
+# @S3method plot ts
+# @method plot ts
 #' @import grid
 #' @return A ggplot object if \code{acf} is \code{FALSE}, otherwise \code{TRUE} indicating success.
 #' @param x a \code{\link{ts}} object.
@@ -210,7 +210,7 @@ plot.acf <- function(x,
 #' plot(sunspot.year)
 #' plot(sunspot.year, acf=TRUE)
 #' 
-plot.ts <- function(x, time=NULL, acf=FALSE,
+plotTimesSeries <- function(x, time=NULL, acf=FALSE,
                     lag.max=NULL, na.action=na.fail, demean=TRUE, 
                     title=sprintf("%s Plot", name), xlab="Time", ylab=name, ...)
 {
@@ -243,4 +243,4 @@ plot.ts <- function(x, time=NULL, acf=FALSE,
     
     #list(tsPlot, acfPlot, pacfPlot)
     invisible(TRUE)
-}
\ No newline at end of file
+}
